@@ -50,6 +50,7 @@ var globals_dup =
     [ "dict_", "globals_d.html", null ],
     [ "dire", "globals_d.html", null ],
     [ "direc", "globals_d.html", null ],
+    [ "dtoa", "globals_d.html", null ],
     [ "endp", "globals_e.html", null ],
     [ "event", "globals_e.html", null ],
     [ "expor", "globals_e.html", null ],
@@ -211,6 +212,7 @@ var globals_dup =
     [ "strin", "globals_s.html", null ],
     [ "strne", "globals_s.html", null ],
     [ "strst", "globals_s.html", null ],
+    [ "strto", "globals_s.html", null ],
     [ "suppo", "globals_s.html", null ],
     [ "swap", "globals_s.html", null ],
     [ "syste", "globals_s.html", null ],
