@@ -58,26 +58,26 @@ var NAVTREEINDEX =
 "annotated.html",
 "globals_defs_p.html",
 "globals_l.html",
-"group__pw__core.html",
-"group__pw__impl__metadata.html#ga400e2176366436ac8752c563400a8eda",
-"group__pw__log.html#ga073d2e07bc95bf80bb43e9d863bd2c8e",
-"group__pw__profiler.html#ga2270ff65dd05ec8d44b575d345b34ef7",
-"group__pw__session__manager.html#gab48a226b48e006093ea7849eada7a806",
-"group__spa__ansi.html#gad9ac3e26ccd0b443d1dcfcbbb6222b3e",
-"group__spa__device.html#gae5c1deaf4987a5c43c1462e46f18b19b",
-"group__spa__log.html#gaac5c4e7126208e70c4f68e5c0354544a",
-"group__spa__node.html#gafda72bd4c75a0c9111ad4106a15d2b3e",
-"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586a00dbc0b5d88eb993c91cdc08e92cdf50",
-"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81afec5c9d4cb1dc263bc4a05291230422c",
-"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea06d203d1c216b0d496cd008447828c14",
-"group__spa__pod.html#ga85016b1c73cf76d8c4789a6f539ac4ec",
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a14f9bce34113fee61a81ccaea5b6677b",
-"page_pulseaudio.html#autotoc_md153",
-"structpw__endpoint__link__info.html#aea87c1744850124ef9bc31d92af578f1",
-"structpw__node__info.html#add4c3cdb14e0baa27c6c28d8c4a4d7f1",
-"structspa__command.html#abf1578cf1ed69aac1d0473684f804d4e",
-"structspa__loop__control.html#a392f811fbacb15de863fc0265031050f",
-"structspa__result__device__params__data.html#aacff758b17616a531f27a4b8361142ce"
+"group__pw__control.html",
+"group__pw__impl__link.html#gacc36539d4d6dfb2064d0ffa36b13d0ae",
+"group__pw__link.html#gga7859f6eb040fead1673d0214b83b445ba369af04b8025470a27c313640bbb4bc0",
+"group__pw__port.html#gafaf94d5ec6fb0f925c2f70a34b8ed190",
+"group__pw__session__manager.html#gaaa4097e754be1ef65c9cd385043ef35c",
+"group__spa__ansi.html#gab2f81c97caf8615cf3d9399aec7ee601",
+"group__spa__device.html#gad20dd1ca2095057a6af2ad7601947e49",
+"group__spa__log.html#ga73863d235426379d73a1defd3191877c",
+"group__spa__node.html#gaf0edf0bcb3ae5739c7a528dc99fab618",
+"group__spa__param.html#gaeff8b2b0ae279f80bce7b0765e39ccd9",
+"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81acabf59a8bfe97068a9c6d98173b6aef7",
+"group__spa__param.html#ggacf6ba1ad0a715f691fcc3105cdffc30daa386d5660ebd59714792b129973b4be3",
+"group__spa__pod.html#ga7dcee1f3ff7993a0b3f80c224977d1f4",
+"group__spa__types.html#gad9c69f01ba4f4907c8550164be6d3d49",
+"page_proxy.html#sec_page_proxy_create",
+"structpw__endpoint__link__events.html",
+"structpw__module__methods.html#ace8dfde4c073903664ba703b575f6e01",
+"structspa__buffer__alloc__info.html#a51af051b079634c3f854680f118716e7",
+"structspa__latency__info.html#a9b3d5d2e366d8081d91adcf736b15c48",
+"structspa__poll__event.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
