@@ -1,5 +1,13 @@
 var NAVTREEINDEX10 =
 {
+"group__spa__log.html#ga73863d235426379d73a1defd3191877c":[6,8,9,3,40],
+"group__spa__log.html#ga750a6ac2af9bf84c4b59af14d6cbe22f":[6,8,9,3,12],
+"group__spa__log.html#ga7d4019336333f5cdf8b82514a6865b79":[6,8,9,3,37],
+"group__spa__log.html#ga8aeddf0fbcac9650fcfc23c58cf991d6":[6,8,9,3,23],
+"group__spa__log.html#ga90d35e35eb3b712e6a74f95c89562d72":[6,8,9,3,24],
+"group__spa__log.html#ga9680fab963b6dc9daf3c1cf2464e53f1":[6,8,9,3,5],
+"group__spa__log.html#ga9b5e43d9eae0e03aba5f126d31839cf1":[6,8,9,3,18],
+"group__spa__log.html#gaa8b31792643b981ff8a7313b26d9d6db":[6,8,9,3,20],
 "group__spa__log.html#gaac5c4e7126208e70c4f68e5c0354544a":[6,8,9,3,34],
 "group__spa__log.html#gaae4067126110801d47890be91be83c5e":[6,8,9,3,9],
 "group__spa__log.html#gaafe9ed56ef18db91a0b25ad7a6ffe620":[6,8,9,3,22],
@@ -241,13 +249,5 @@ var NAVTREEINDEX10 =
 "group__spa__node.html#gae881bab892a51d30cf3959fb03016b13":[6,8,6,89],
 "group__spa__node.html#gaed43186ba554d0253f721dda55ffe84d":[6,8,6,102],
 "group__spa__node.html#gaee7d45b6819789bde3de86d9be592a3a":[6,8,6,119],
-"group__spa__node.html#gaeee49d051bb080669113c6deeffa5d90":[6,8,6,80],
-"group__spa__node.html#gaf0edf0bcb3ae5739c7a528dc99fab618":[6,8,6,64],
-"group__spa__node.html#gaf2eed3ad98da6b63c5f28960c7c0af5b":[6,8,6,28],
-"group__spa__node.html#gaf4fd1fa9983cfe26d6d3a08bc34c8230":[6,8,6,149],
-"group__spa__node.html#gaf6acc77e506b002f4af0ecd03e29c6ff":[6,8,6,120],
-"group__spa__node.html#gaf7f6bdf00d83c8aaa4cb13c983ff3ff6":[6,8,6,132],
-"group__spa__node.html#gaf9f1bf717bf713b7c019934218c05a5c":[6,8,6,118],
-"group__spa__node.html#gafab7e244874674b26e9f688d5fec8591":[6,8,6,55],
-"group__spa__node.html#gafc6f880a7906ab6ad837b753b6c2de05":[6,8,6,122]
+"group__spa__node.html#gaeee49d051bb080669113c6deeffa5d90":[6,8,6,80]
 };
