@@ -1,5 +1,13 @@
 var NAVTREEINDEX15 =
 {
+"group__spa__pod.html#ga7dcee1f3ff7993a0b3f80c224977d1f4":[6,8,0,119],
+"group__spa__pod.html#ga7f59bef75b6bc82839180380bf3c3dd5":[6,8,0,72],
+"group__spa__pod.html#ga7fda864b19555161ffa6b0bce9045fa8":[6,8,0,316],
+"group__spa__pod.html#ga80c22ac336bb35f14a3692372f13c01f":[6,8,0,152],
+"group__spa__pod.html#ga80c5ed3cda1e515557a76c920fcb47fe":[6,8,0,320],
+"group__spa__pod.html#ga81a0efc821fbd7906e1a7f3f9938533c":[6,8,0,285],
+"group__spa__pod.html#ga82aaa527c390ad8839f4aa165975b307":[6,8,0,275],
+"group__spa__pod.html#ga82e4fb3f51ce8215e63bfb0eefc812e9":[6,8,0,231],
 "group__spa__pod.html#ga85016b1c73cf76d8c4789a6f539ac4ec":[6,8,0,195],
 "group__spa__pod.html#ga86b759c508891cf57a9c1d2a5690a20f":[6,8,0,106],
 "group__spa__pod.html#ga86cb2bcc11e2f431ba87fcdab9f5f58b":[6,8,0,273],
@@ -157,19 +165,22 @@ var NAVTREEINDEX15 =
 "group__spa__ringbuffer.html#gadaacf8c44d93c41c4e6e34b1df310fd3":[6,8,8,10,9],
 "group__spa__ringbuffer.html#gae84a3778b64a5e9dbccb8f75b50e3f99":[6,8,8,10,8],
 "group__spa__string.html":[6,8,8,11],
-"group__spa__string.html#ga0b03d1967a0ee32027c1efb16fec49de":[6,8,8,11,13],
+"group__spa__string.html#ga0b03d1967a0ee32027c1efb16fec49de":[6,8,8,11,15],
 "group__spa__string.html#ga0b9d09a3a4f68c4a5e55e350caeb67fb":[6,8,8,11,8],
 "group__spa__string.html#ga0d201c72eaebf5c235c2c1790ca6da4e":[6,8,8,11,3],
+"group__spa__string.html#ga0faf9c1cc2f41796a16399193bbdb263":[6,8,8,11,14],
 "group__spa__string.html#ga16da26e2202a32c64061f92dec72dfc5":[6,8,8,11,9],
 "group__spa__string.html#ga1f07c2f2d56ba170bf23d472153494e5":[6,8,8,11,7],
 "group__spa__string.html#ga2aedff000d734290adf11899c5fcb896":[6,8,8,11,6],
 "group__spa__string.html#ga6ddf76d4003737cda2ba9b160aa8dfa8":[6,8,8,11,5],
 "group__spa__string.html#ga7f9387d004bd1dde300f434f2987e58e":[6,8,8,11,4],
 "group__spa__string.html#ga8a13832c182bd96cdeb32e93d0a5f4cf":[6,8,8,11,2],
+"group__spa__string.html#ga928368a5adc237123fe3097ddf09061d":[6,8,8,11,12],
 "group__spa__string.html#gab9f2fbcc3c33f77f37e9f00941f387b6":[6,8,8,11,10],
 "group__spa__string.html#gaccfedc485cb2e3bef649e77ee6db26ab":[6,8,8,11,1],
-"group__spa__string.html#gace4942742ce246641a3cb3b4b2540e05":[6,8,8,11,12],
+"group__spa__string.html#gace4942742ce246641a3cb3b4b2540e05":[6,8,8,11,13],
 "group__spa__string.html#gae194d9bc956defbfe180dc658e3df052":[6,8,8,11,11],
+"group__spa__string.html#gae9be2db04a7f11c3ff07b78f635c9fe3":[6,8,8,11,16],
 "group__spa__support.html":[6,8,9],
 "group__spa__system.html":[6,8,9,7],
 "group__spa__system.html#ga0dd7ca3def67660ca1aa93c87f5d88a5":[6,8,9,7,15],
@@ -238,16 +249,5 @@ var NAVTREEINDEX15 =
 "group__spa__types.html#gaaca7a372068124b38f09b0bd2fef0f98":[6,8,8,12,4],
 "group__spa__types.html#gab8f02181d37e1c034e04797628a8ee1b":[6,8,8,12,5],
 "group__spa__types.html#gacca81d9bddca49922a0945a9b58b5e39":[6,8,8,12,21],
-"group__spa__types.html#gad3685dd5b8d7658dd24b77fad4a721bc":[6,8,8,12,20],
-"group__spa__types.html#gad9c69f01ba4f4907c8550164be6d3d49":[6,8,8,12,10],
-"group__spa__types.html#gaecaf5a9f0c1bd9c31611d0fdf18fe7a2":[6,8,8,12,17],
-"group__spa__types.html#gafb8bf694625474ebfb1ecdce28bb4828":[6,8,8,12,30],
-"group__spa__types.html#gafbabcef02a8226b94cd9708d0e3bda6c":[6,8,8,12,3],
-"group__spa__types.html#gafed08c224994e5fa76c5503bd4e476dd":[6,8,8,12,26],
-"group__spa__types.html#gafff747a1e17cacd06f036b94ad100aaa":[6,8,8,12,28],
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a0167cc2e8efa1a4b616e72c738bc1b3a":[6,8,8,12,26,23],
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a07c6c317beb0840af6c989b35e497e94":[6,8,8,12,26,43],
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a08878f07dded510b5965257093dd604e":[6,8,8,12,26,4],
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a0d689fa3897dcc16fdeb08814cb251ca":[6,8,8,12,26,42],
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a1195438b5c43f33a3fe50accde463f9b":[6,8,8,12,26,31]
+"group__spa__types.html#gad3685dd5b8d7658dd24b77fad4a721bc":[6,8,8,12,20]
 };
