@@ -1,5 +1,19 @@
 var NAVTREEINDEX17 =
 {
+"page_proxy.html#sec_page_proxy_create":[4,1,2],
+"page_proxy.html#sec_page_proxy_destroy":[4,1,6],
+"page_proxy.html#sec_page_proxy_events":[4,1,5],
+"page_proxy.html#sec_page_proxy_methods":[4,1,4],
+"page_proxy.html#sec_page_proxy_overview":[4,1,0],
+"page_pulseaudio.html":[1,11],
+"page_pulseaudio.html#autotoc_md145":[1,11,0],
+"page_pulseaudio.html#autotoc_md146":[1,11,0,0],
+"page_pulseaudio.html#autotoc_md147":[1,11,0,1],
+"page_pulseaudio.html#autotoc_md148":[1,11,1],
+"page_pulseaudio.html#autotoc_md149":[1,11,1,0],
+"page_pulseaudio.html#autotoc_md150":[1,11,1,1],
+"page_pulseaudio.html#autotoc_md151":[1,11,1,2],
+"page_pulseaudio.html#autotoc_md152":[1,11,1,3],
 "page_pulseaudio.html#autotoc_md153":[1,11,2],
 "page_session_manager.html":[1,10],
 "page_spa.html":[5],
@@ -86,6 +100,7 @@ var NAVTREEINDEX17 =
 "structpw__array.html#ab0929cdf2f7acb291f2f17be299b8ea5":[6,6,0,1,0],
 "structpw__buffer.html":[6,0,1],
 "structpw__buffer.html#a925734b861209896789573f3b94a61c1":[6,0,1,2],
+"structpw__buffer.html#ab5fe741ec31686febdbc602098945f08":[6,0,1,3],
 "structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090":[6,0,1,0],
 "structpw__buffer.html#ad85549808ad885c57f85e1aee60b8c96":[6,0,1,1],
 "structpw__buffers.html":[6,5,9,1],
@@ -162,8 +177,8 @@ var NAVTREEINDEX17 =
 "structpw__context__events.html#a9c874d491dfbdd13eb81c7b0b7561e87":[6,4,2,1,2],
 "structpw__context__events.html#ad0a1b4e42b11a408175ab4f70b1bbc7c":[6,4,2,1,0],
 "structpw__context__events.html#af3303a7f003c10bfbb454c0bbd13360c":[6,4,2,1,3],
-"structpw__control.html":[6,5,10,2],
 "structpw__control.html":[6,5,8,4],
+"structpw__control.html":[6,5,10,2],
 "structpw__control__events.html":[6,5,10,1],
 "structpw__control__events.html#a2cda9616fd4aa65d7cc2f8dc6efe69dc":[6,5,10,1,4],
 "structpw__control__events.html#a4d456606837f25ad3e55471ae23c6bdc":[6,5,10,1,0],
@@ -234,20 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__endpoint__info.html#ac9c79172b3c9d4a42d622896d357eb4a":[6,7,4,19,2],
 "structpw__endpoint__info.html#add8888495992bb7b239f5538db21202f":[6,7,4,19,7],
 "structpw__endpoint__info.html#af238696ba49e512e921eea434d3dee54":[6,7,4,19,6],
-"structpw__endpoint__link.html":[6,7,4,27],
-"structpw__endpoint__link__events.html":[6,7,4,16],
-"structpw__endpoint__link__events.html#a49a713f1ca373404a38eb498bcd2f95c":[6,7,4,16,2],
-"structpw__endpoint__link__events.html#ac94440a980f13b2ec1dca2be768d7a2e":[6,7,4,16,0],
-"structpw__endpoint__link__events.html#aea346b16f2b34caf23a7a36fedd6ce3f":[6,7,4,16,1],
-"structpw__endpoint__link__info.html":[6,7,4,21],
-"structpw__endpoint__link__info.html#a07c6bf548b8e042c2812543981a51598":[6,7,4,21,1],
-"structpw__endpoint__link__info.html#a0c23a32dc6e567f7cf483a20c988feb3":[6,7,4,21,7],
-"structpw__endpoint__link__info.html#a1d398555b2824d65fda91cfd3258a813":[6,7,4,21,3],
-"structpw__endpoint__link__info.html#a460974a8c40082a75b90d5d151e93ca7":[6,7,4,21,5],
-"structpw__endpoint__link__info.html#a7effc16feab6bfc6322e96d90ebea27d":[6,7,4,21,9],
-"structpw__endpoint__link__info.html#aaae0e9204b82b599f01bfcafe7573103":[6,7,4,21,0],
-"structpw__endpoint__link__info.html#abbca6b1e2d0509bea65aff817962e0e7":[6,7,4,21,10],
-"structpw__endpoint__link__info.html#abe1a77c360812808ac34d2ab016f6bd7":[6,7,4,21,8],
-"structpw__endpoint__link__info.html#ae0c6caf742470e3133cd0de7a7e642a9":[6,7,4,21,11],
-"structpw__endpoint__link__info.html#aea0b70e668d2c6c0dbec40bfc6b6ff62":[6,7,4,21,4]
+"structpw__endpoint__link.html":[6,7,4,27]
 };
