@@ -1,5 +1,20 @@
 var NAVTREEINDEX19 =
 {
+"structpw__module__methods.html#ace8dfde4c073903664ba703b575f6e01":[6,4,9,3,1],
+"structpw__node.html":[6,4,10,4],
+"structpw__node__events.html":[6,4,10,2],
+"structpw__node__events.html#a07c012e13056aed56de654a44590df89":[6,4,10,2,2],
+"structpw__node__events.html#a37faf21db57a7e95999db521fb1cbcab":[6,4,10,2,0],
+"structpw__node__events.html#a9a6cdaf300007bc554b0c0b6bdbf5ccd":[6,4,10,2,1],
+"structpw__node__info.html":[6,4,10,1],
+"structpw__node__info.html#a125f4d8851630b989c86fc0ebc83fba0":[6,4,10,1,6],
+"structpw__node__info.html#a178dbb8570999efffa8584d13e52ce0e":[6,4,10,1,1],
+"structpw__node__info.html#a48075df9117cf8e55b474c8d2d445a1d":[6,4,10,1,7],
+"structpw__node__info.html#a737754b76140ca4751f2cd68667ffaa2":[6,4,10,1,0],
+"structpw__node__info.html#a88bcfe3c9dbce8c5c6ac7b663e4db009":[6,4,10,1,3],
+"structpw__node__info.html#aa2bd90f2d1c5f570eac18709b2acc387":[6,4,10,1,8],
+"structpw__node__info.html#ab5c2457030a463ccdc6ca5291ced856f":[6,4,10,1,5],
+"structpw__node__info.html#ac312e1844784e77e412f6bb341814372":[6,4,10,1,2],
 "structpw__node__info.html#add4c3cdb14e0baa27c6c28d8c4a4d7f1":[6,4,10,1,9],
 "structpw__node__info.html#ae3b1789c08bcae95888e042790c95b75":[6,4,10,1,4],
 "structpw__node__methods.html":[6,4,10,3],
@@ -164,9 +179,12 @@ var NAVTREEINDEX19 =
 "structpw__time.html":[6,0,3],
 "structpw__time.html#a1ea3fa77ce4221df0d5ac3ad8fd1f6c7":[6,0,3,3],
 "structpw__time.html#a41d793c390eefc6aee165e16e0d7c898":[6,0,3,1],
+"structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff":[6,0,3,5],
 "structpw__time.html#a91dafbb38397328f8705e2bb20b7625a":[6,0,3,4],
+"structpw__time.html#a92d7a1849d4dc044d2fa64bd35a7a57d":[6,0,3,6],
 "structpw__time.html#a99e3d7963e24fbf410afa03c73465328":[6,0,3,2],
 "structpw__time.html#ad817da21bea1591d70f837c251a73468":[6,0,3,0],
+"structpw__time.html#aebd42745267531bc23e1ee34dd759607":[6,0,3,7],
 "structpw__work__queue.html":[6,5,16,1],
 "structpwtest__context.html":[6,2,2],
 "structpwtest__spa__plugin.html":[6,2,1],
@@ -231,23 +249,5 @@ var NAVTREEINDEX19 =
 "structspa__buffer__alloc__info.html":[6,8,1,4],
 "structspa__buffer__alloc__info.html#a2598f62c920f42fd1ea6547968c0e2a6":[6,8,1,4,11],
 "structspa__buffer__alloc__info.html#a30233569ad362f458d9e1344d0b5a58c":[6,8,1,4,10],
-"structspa__buffer__alloc__info.html#a49810ff55f219eea5c1e4a3e2f24cd4c":[6,8,1,4,2],
-"structspa__buffer__alloc__info.html#a51af051b079634c3f854680f118716e7":[6,8,1,4,1],
-"structspa__buffer__alloc__info.html#a63296028aeb53c2e98501c78f1d53617":[6,8,1,4,8],
-"structspa__buffer__alloc__info.html#a8ea4df582a468b0f1621672af3e2426f":[6,8,1,4,9],
-"structspa__buffer__alloc__info.html#a963cf1755ba6612abcff0491680abc64":[6,8,1,4,7],
-"structspa__buffer__alloc__info.html#adea010a789fec41087739852b235185b":[6,8,1,4,5],
-"structspa__buffer__alloc__info.html#ae0f8e64c4f71c63cfa87b1b7527a47c7":[6,8,1,4,6],
-"structspa__buffer__alloc__info.html#aea2d60a678ae26619b5bfb35291b9a01":[6,8,1,4,3],
-"structspa__buffer__alloc__info.html#aef6e15022383cf49cbba4196111c190d":[6,8,1,4,4],
-"structspa__buffer__alloc__info.html#afc286a004cefa1ef2d751483a8cc8c15":[6,8,1,4,0],
-"structspa__callbacks.html":[6,8,8,5,1],
-"structspa__callbacks.html#a0c52caccee37692f842b93785b3f7f22":[6,8,8,5,1,0],
-"structspa__callbacks.html#adc0097ae82d42b5fc92e896f47e13ee5":[6,8,8,5,1,1],
-"structspa__chunk.html":[6,8,1,5],
-"structspa__chunk.html#a5a6f66c73b76acf608ef18846d539df2":[6,8,1,5,2],
-"structspa__chunk.html#a73c84537a6f3a0da168f765cb3558735":[6,8,1,5,1],
-"structspa__chunk.html#ae77eb3c5ecf94cc2b80c306afd7a6768":[6,8,1,5,3],
-"structspa__chunk.html#ae7a889b81a5d56ff5babd521b5ce7cb7":[6,8,1,5,0],
-"structspa__command.html":[6,8,0,13]
+"structspa__buffer__alloc__info.html#a49810ff55f219eea5c1e4a3e2f24cd4c":[6,8,1,4,2]
 };
