@@ -1,5 +1,23 @@
 var NAVTREEINDEX20 =
 {
+"structspa__buffer__alloc__info.html#a51af051b079634c3f854680f118716e7":[6,8,1,4,1],
+"structspa__buffer__alloc__info.html#a63296028aeb53c2e98501c78f1d53617":[6,8,1,4,8],
+"structspa__buffer__alloc__info.html#a8ea4df582a468b0f1621672af3e2426f":[6,8,1,4,9],
+"structspa__buffer__alloc__info.html#a963cf1755ba6612abcff0491680abc64":[6,8,1,4,7],
+"structspa__buffer__alloc__info.html#adea010a789fec41087739852b235185b":[6,8,1,4,5],
+"structspa__buffer__alloc__info.html#ae0f8e64c4f71c63cfa87b1b7527a47c7":[6,8,1,4,6],
+"structspa__buffer__alloc__info.html#aea2d60a678ae26619b5bfb35291b9a01":[6,8,1,4,3],
+"structspa__buffer__alloc__info.html#aef6e15022383cf49cbba4196111c190d":[6,8,1,4,4],
+"structspa__buffer__alloc__info.html#afc286a004cefa1ef2d751483a8cc8c15":[6,8,1,4,0],
+"structspa__callbacks.html":[6,8,8,5,1],
+"structspa__callbacks.html#a0c52caccee37692f842b93785b3f7f22":[6,8,8,5,1,0],
+"structspa__callbacks.html#adc0097ae82d42b5fc92e896f47e13ee5":[6,8,8,5,1,1],
+"structspa__chunk.html":[6,8,1,5],
+"structspa__chunk.html#a5a6f66c73b76acf608ef18846d539df2":[6,8,1,5,2],
+"structspa__chunk.html#a73c84537a6f3a0da168f765cb3558735":[6,8,1,5,1],
+"structspa__chunk.html#ae77eb3c5ecf94cc2b80c306afd7a6768":[6,8,1,5,3],
+"structspa__chunk.html#ae7a889b81a5d56ff5babd521b5ce7cb7":[6,8,1,5,0],
+"structspa__command.html":[6,8,0,13],
 "structspa__command.html#abf1578cf1ed69aac1d0473684f804d4e":[6,8,0,13,1],
 "structspa__command.html#ad422c2065f2080f39a1ee42b77154c55":[6,8,0,13,0],
 "structspa__command__body.html":[6,8,0,12],
@@ -69,6 +87,14 @@ var NAVTREEINDEX20 =
 "structspa__dict__item.html":[6,8,8,2,1],
 "structspa__dict__item.html#a16dc8153e2ea77c9c82380456734478a":[6,8,8,2,1,0],
 "structspa__dict__item.html#af08479e3ff870039be002b436a02457d":[6,8,8,2,1,1],
+"structspa__dll.html":[7,0,167],
+"structspa__dll.html#a6e71bca8352ac6213b6d26c22732c9a1":[7,0,167,2],
+"structspa__dll.html#a7b2d7a0adb6cdc3680db685fef886d78":[7,0,167,1],
+"structspa__dll.html#a90a86177cee5a8c972d4a2825244d3de":[7,0,167,6],
+"structspa__dll.html#aa109171408f82fa3f287b70e2396ba42":[7,0,167,3],
+"structspa__dll.html#aa99d781b6e4c1133db7bef843fc4a21a":[7,0,167,4],
+"structspa__dll.html#ac3de731c327763f69c44e98224ee1068":[7,0,167,0],
+"structspa__dll.html#ae1e3a33d3f38548692173d283b613574":[7,0,167,5],
 "structspa__event.html":[6,8,0,15],
 "structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb":[6,8,0,15,1],
 "structspa__event.html#a2411141eed88d3587687a8d86c99d488":[6,8,0,15,0],
@@ -223,31 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__json.html#ae765edf5a3ac4c7fe5be87c93f62b0c2":[6,8,8,6,1,2],
 "structspa__latency__info.html":[6,8,7,25],
 "structspa__latency__info.html#a114447a982c76675818ca5fff6e5b101":[6,8,7,25,3],
-"structspa__latency__info.html#a7950ed27a0b4e341e1c852fb5ca6e4ec":[6,8,7,25,4],
-"structspa__latency__info.html#a9b3d5d2e366d8081d91adcf736b15c48":[6,8,7,25,0],
-"structspa__latency__info.html#aab5617769d3799f99a80747917268db8":[6,8,7,25,2],
-"structspa__latency__info.html#aadaa9a123ffe5f4a050945e210cc5725":[6,8,7,25,1],
-"structspa__latency__info.html#ac9e3498891f63e0c2f6e6df171febb5b":[6,8,7,25,5],
-"structspa__latency__info.html#ae4923a45e4de7d99b8aa658c4e59235e":[6,8,7,25,6],
-"structspa__list.html":[6,8,8,3,1],
-"structspa__list.html#ab67df98c96319f199a02cb48ee7de93e":[6,8,8,3,1,1],
-"structspa__list.html#aed4aa24d6a3d4f62a4198296312a6196":[6,8,8,3,1,0],
-"structspa__log.html":[6,8,9,3,2],
-"structspa__log.html#a2904120a458d402fce2b316280f677c6":[6,8,9,3,2,0],
-"structspa__log.html#aeb76fd47b796f30c75d48512b390cedb":[6,8,9,3,2,1],
-"structspa__log__methods.html":[6,8,9,3,4],
-"structspa__log__methods.html#a36c36dd974369f8c679c3191399a4ab4":[6,8,9,3,4,3],
-"structspa__log__methods.html#a3c9b289423cdd729b13d7b3311f1a637":[6,8,9,3,4,0],
-"structspa__log__methods.html#a51595ad4d11e427ae19bb28502d96b13":[6,8,9,3,4,5],
-"structspa__log__methods.html#a5b42d0cf1f39f36bb70f513de84e3ece":[6,8,9,3,4,2],
-"structspa__log__methods.html#a7d45621105c15f6dca5549c8cc6920b7":[6,8,9,3,4,1],
-"structspa__log__methods.html#aeab0c4322dacb80bfd82b4de6081e025":[6,8,9,3,4,4],
-"structspa__log__topic.html":[6,8,9,3,3],
-"structspa__log__topic.html#a03003ed60b6acc4788b41e74b9945911":[6,8,9,3,3,0],
-"structspa__log__topic.html#a1295d4049013c031f7c30074182dfe58":[6,8,9,3,3,3],
-"structspa__log__topic.html#a23fb58684c75ff5cadeda72fa6ea1f92":[6,8,9,3,3,2],
-"structspa__log__topic.html#ab77cbaf7b01d2f4dddbcf7f51766b9d6":[6,8,9,3,3,1],
-"structspa__loop.html":[6,8,9,4,1],
-"structspa__loop.html#a6cd472082b361bc90f66c41b0dccea96":[6,8,9,4,1,0],
-"structspa__loop__control.html":[6,8,9,4,2]
+"structspa__latency__info.html#a7950ed27a0b4e341e1c852fb5ca6e4ec":[6,8,7,25,4]
 };
