@@ -1,5 +1,10 @@
 var NAVTREEINDEX7 =
 {
+"group__pw__session__manager.html#gaaa4097e754be1ef65c9cd385043ef35c":[6,7,4,131],
+"group__pw__session__manager.html#gaac78e333b32802852a748a59122c31b1":[6,7,4,80],
+"group__pw__session__manager.html#gaad4ee430040387376438b0326e163d6d":[6,7,4,150],
+"group__pw__session__manager.html#gab104098c9fd6fad4bbe290509aefbe20":[6,7,4,182],
+"group__pw__session__manager.html#gab2aa7fe3e4c589dcf0e448bff2addf4e":[6,7,4,156],
 "group__pw__session__manager.html#gab48a226b48e006093ea7849eada7a806":[6,7,4,91],
 "group__pw__session__manager.html#gab62fb0a5129ee8d80c2f898aaa48b6ff":[6,7,4,87],
 "group__pw__session__manager.html#gab87d0172d9534c14ff37a25a14deefd9":[6,7,4,161],
@@ -61,24 +66,25 @@ var NAVTREEINDEX7 =
 "group__pw__stream.html#ga087a686c66c04e54742cc94c7a5e4e68":[6,0,14],
 "group__pw__stream.html#ga0c274f28a9b9b2fe286719db159f166b":[6,0,23],
 "group__pw__stream.html#ga0e12176f13e654e64e7f5689e7a6dd54":[6,0,19],
-"group__pw__stream.html#ga0ed34dd74ca8f5f46db7c2a4cbd45a94":[6,0,27],
+"group__pw__stream.html#ga0ed34dd74ca8f5f46db7c2a4cbd45a94":[6,0,28],
 "group__pw__stream.html#ga1744b8f160ac0f8d377db9bfdab57053":[6,0,20],
 "group__pw__stream.html#ga19f542ff2b8a51336ae78cfaec8ed896":[6,0,22],
 "group__pw__stream.html#ga2d5e07833039ac7a202caaf297556f52":[6,0,25],
-"group__pw__stream.html#ga3ddd332c45aa95250d3d1d26cf01452a":[6,0,31],
-"group__pw__stream.html#ga5ef987fd1903baa7eba9b10a8cbf5e97":[6,0,30],
+"group__pw__stream.html#ga3ddd332c45aa95250d3d1d26cf01452a":[6,0,32],
+"group__pw__stream.html#ga5ef987fd1903baa7eba9b10a8cbf5e97":[6,0,31],
 "group__pw__stream.html#ga712ca485dc634252d144556074980f0a":[6,0,10],
-"group__pw__stream.html#ga721dc4d5ec4c406ecb0469bfefea468f":[6,0,26],
+"group__pw__stream.html#ga721dc4d5ec4c406ecb0469bfefea468f":[6,0,27],
 "group__pw__stream.html#ga8a3e7ddb0e61c4266ce735a085adb5e7":[6,0,24],
 "group__pw__stream.html#ga8b023e0bc564e4e8f70cec17e7c608f4":[6,0,9],
 "group__pw__stream.html#ga9ceaca6fc9acd9a1af080258d763fb82":[6,0,7],
 "group__pw__stream.html#gaa727d7a41acb9d0ec574f93f01328d30":[6,0,21],
-"group__pw__stream.html#gaafa1055c167dd99ba94bb49ec30603ba":[6,0,29],
-"group__pw__stream.html#gab93fa91d8ea80e562bb5e8f6b5bafe21":[6,0,32],
-"group__pw__stream.html#gabe1c593f34080ea9c8c6231abe4e7386":[6,0,28],
+"group__pw__stream.html#gaafa1055c167dd99ba94bb49ec30603ba":[6,0,30],
+"group__pw__stream.html#gab93fa91d8ea80e562bb5e8f6b5bafe21":[6,0,33],
+"group__pw__stream.html#gabe1c593f34080ea9c8c6231abe4e7386":[6,0,29],
 "group__pw__stream.html#gaca974f99f4545ce623a94c2f06a48dd0":[6,0,15],
 "group__pw__stream.html#gacdd761aac33011a41d1f05cfe9effb11":[6,0,11],
 "group__pw__stream.html#gad9606e2efb479a55ee798f61b82aa49b":[6,0,17],
+"group__pw__stream.html#gadde95a60798bfffa6575306bc07ee7f4":[6,0,26],
 "group__pw__stream.html#gadfa74620109228a9cfce24b628aa130f":[6,0,13],
 "group__pw__stream.html#gaf21c1b002f78067d2eca97c455970822":[6,0,6],
 "group__pw__stream.html#gaf48f79b09798488557cd6c2f896e0891":[6,0,12],
@@ -171,6 +177,7 @@ var NAVTREEINDEX7 =
 "group__pwtest.html#ga60aaaf4bca029a7cd77d9e2328cc33b0":[6,2,27],
 "group__pwtest.html#ga66c238ea82ddcd0fc1228b79084c8bd4":[6,2,10],
 "group__pwtest.html#ga67d03b7d6a735f8d4568ddda45a200f9":[6,2,13],
+"group__pwtest.html#ga71b64f3667b94c8200d47c3e28cff9e5":[6,2,52],
 "group__pwtest.html#ga725688a342b197bd0ba624c8c28f04e1":[6,2,36],
 "group__pwtest.html#ga73a6c78f94e35f2b7789268c01ef11c2":[6,2,30],
 "group__pwtest.html#ga7817ddf65dee003c061bc129ef2e68cd":[6,2,21],
@@ -242,12 +249,5 @@ var NAVTREEINDEX7 =
 "group__spa__ansi.html#gaa1a2ac28f17e74bb15ca4c4110c65dd5":[6,8,8,0,46],
 "group__spa__ansi.html#gaa8e085e38fa2f989abeccfeef670fe54":[6,8,8,0,8],
 "group__spa__ansi.html#gaad15091a1f40cc819dff1fc80374cc34":[6,8,8,0,4],
-"group__spa__ansi.html#gab2d591c87fb435e76e453d03be99df8f":[6,8,8,0,47],
-"group__spa__ansi.html#gab2f81c97caf8615cf3d9399aec7ee601":[6,8,8,0,6],
-"group__spa__ansi.html#gab904421bf8255a770bfc02ea7262ef19":[6,8,8,0,25],
-"group__spa__ansi.html#gabcf2363d262cee0526346177c9246c92":[6,8,8,0,24],
-"group__spa__ansi.html#gac75fc46d7948111d087d9dd444cbcb6e":[6,8,8,0,7],
-"group__spa__ansi.html#gacc92b4eb940bdf521a96b02f0261fb6d":[6,8,8,0,32],
-"group__spa__ansi.html#gace360eddb3a5fca36e9a3730606f6fad":[6,8,8,0,10],
-"group__spa__ansi.html#gad05b2989634f1bdd58adce5724527574":[6,8,8,0,29]
+"group__spa__ansi.html#gab2d591c87fb435e76e453d03be99df8f":[6,8,8,0,47]
 };
