@@ -1,5 +1,12 @@
 var NAVTREEINDEX9 =
 {
+"group__spa__device.html#gad20dd1ca2095057a6af2ad7601947e49":[6,8,4,42],
+"group__spa__device.html#gad97ce15937ee02d483156a0937260f76":[6,8,4,56],
+"group__spa__device.html#gadef390bb7a8fbcfca7bf01639ed6b9e6":[6,8,4,40],
+"group__spa__device.html#gae011d2c6dce34040bfe95c9a5b0a8fc4":[6,8,4,58],
+"group__spa__device.html#gae3d33bd6e79f4fdb1a19402def48e044":[6,8,4,79],
+"group__spa__device.html#gae4f6fcd5af1159ca52a6e032174e0555":[6,8,4,39],
+"group__spa__device.html#gae5a43b17b5a707684dfedb342082ef58":[6,8,4,35],
 "group__spa__device.html#gae5c1deaf4987a5c43c1462e46f18b19b":[6,8,4,19],
 "group__spa__device.html#gae60303388ab0418d8f8af5b3e8a80645":[6,8,4,16],
 "group__spa__device.html#gae7e76cf0948e77e7ca648babb7f1f210":[6,8,4,52],
@@ -108,35 +115,36 @@ var NAVTREEINDEX9 =
 "group__spa__interfaces.html#gafbe7e2c178c8649d89fe3d6cfcb74c65":[6,8,8,5,4],
 "group__spa__json.html":[6,8,8,6],
 "group__spa__json.html#ga04a8b54928642e8bc49077d7f26e57a5":[6,8,8,6,10],
-"group__spa__json.html#ga07e1f5cda4b1894f6165805159d11faa":[6,8,8,6,27],
+"group__spa__json.html#ga07e1f5cda4b1894f6165805159d11faa":[6,8,8,6,28],
 "group__spa__json.html#ga0d0d13b703fb3bf42b6a96b11973767a":[6,8,8,6,4],
 "group__spa__json.html#ga16c676cb24334b96a9e1eaf0d73ec39f":[6,8,8,6,17],
 "group__spa__json.html#ga255f1962c8cb52c861c197533693732c":[6,8,8,6,16],
-"group__spa__json.html#ga2b070aa36336cbe95ffe1871672ecd70":[6,8,8,6,22],
-"group__spa__json.html#ga2fe3d2f299b7227b36c93c84c0117f96":[6,8,8,6,28],
+"group__spa__json.html#ga2b070aa36336cbe95ffe1871672ecd70":[6,8,8,6,23],
+"group__spa__json.html#ga2fe3d2f299b7227b36c93c84c0117f96":[6,8,8,6,29],
 "group__spa__json.html#ga4dbbb0d8d43216c23d20b08be1650437":[6,8,8,6,8],
 "group__spa__json.html#ga54e9a5e2c169224c8ae8953135290505":[6,8,8,6,6],
-"group__spa__json.html#ga5e367b9297cbf21d391f4d1b2ffe4734":[6,8,8,6,23],
-"group__spa__json.html#ga604d3512668501ff1a1d5897c0208416":[6,8,8,6,21],
-"group__spa__json.html#ga62fe1f66450b557cf2c5b5e65a5fcd70":[6,8,8,6,25],
+"group__spa__json.html#ga5e367b9297cbf21d391f4d1b2ffe4734":[6,8,8,6,24],
+"group__spa__json.html#ga604d3512668501ff1a1d5897c0208416":[6,8,8,6,22],
+"group__spa__json.html#ga62fe1f66450b557cf2c5b5e65a5fcd70":[6,8,8,6,26],
 "group__spa__json.html#ga6502b3572751902a364273b0cdaa13c4":[6,8,8,6,12],
-"group__spa__json.html#ga6864ecec42015a48aa8991d6a2c8d6fa":[6,8,8,6,30],
-"group__spa__json.html#ga6c02b51e71c406e5b7f014858bdf579b":[6,8,8,6,24],
+"group__spa__json.html#ga6864ecec42015a48aa8991d6a2c8d6fa":[6,8,8,6,31],
+"group__spa__json.html#ga6c02b51e71c406e5b7f014858bdf579b":[6,8,8,6,25],
 "group__spa__json.html#ga6d871debd28993273c3cbb1b0f7fce64":[6,8,8,6,2],
+"group__spa__json.html#ga7c080249c08879b0576e5225a67fde7e":[6,8,8,6,19],
 "group__spa__json.html#ga8e5fa24c312810edffc063169e55497d":[6,8,8,6,13],
-"group__spa__json.html#ga910d92b40deefb1451ddcdee9b96c243":[6,8,8,6,26],
+"group__spa__json.html#ga910d92b40deefb1451ddcdee9b96c243":[6,8,8,6,27],
 "group__spa__json.html#ga9110761cf050dd015410b949edd24350":[6,8,8,6,15],
 "group__spa__json.html#ga9e5319ac5846fb6219a973e0cfa46786":[6,8,8,6,3],
-"group__spa__json.html#gab03680b46f934bdc18755d2156077cf1":[6,8,8,6,31],
-"group__spa__json.html#gabc34f55fde305ab5ff6a28d34a642170":[6,8,8,6,19],
+"group__spa__json.html#gab03680b46f934bdc18755d2156077cf1":[6,8,8,6,32],
+"group__spa__json.html#gabc34f55fde305ab5ff6a28d34a642170":[6,8,8,6,20],
 "group__spa__json.html#gac6aa5f68834748dc6790cf5dd2ac9401":[6,8,8,6,7],
 "group__spa__json.html#gacc0420e669d2d9ab67bf711a63373026":[6,8,8,6,9],
 "group__spa__json.html#gacda21b833e3e2e8ed1b8bc42bf017ee9":[6,8,8,6,5],
-"group__spa__json.html#gace48d5f93c0be66297f2389175de2ee0":[6,8,8,6,20],
+"group__spa__json.html#gace48d5f93c0be66297f2389175de2ee0":[6,8,8,6,21],
 "group__spa__json.html#gad27e11f0d644f60840cb42bdcc370412":[6,8,8,6,14],
 "group__spa__json.html#gad655166a86f6b9b79fb480603bf63ec3":[6,8,8,6,18],
 "group__spa__json.html#gae465abe3ff0170d6b630ead5901fba56":[6,8,8,6,11],
-"group__spa__json.html#gae51e8d4cc1999ffcc20802cc9e3f8a97":[6,8,8,6,29],
+"group__spa__json.html#gae51e8d4cc1999ffcc20802cc9e3f8a97":[6,8,8,6,30],
 "group__spa__json__pod.html":[6,3],
 "group__spa__json__pod.html#ga7904434cb7205e5aa65caa9a7d225e77":[6,3,2],
 "group__spa__json__pod.html#gaffbc97d3a2e34cca3c9735634c2a3013":[6,3,1],
@@ -241,13 +249,5 @@ var NAVTREEINDEX9 =
 "group__spa__log.html#ga54294a1ab30713deee27d8165fb7bd67":[6,8,9,3,6],
 "group__spa__log.html#ga57e9358ebf5d48ede482791857f234a8":[6,8,9,3,39],
 "group__spa__log.html#ga5989502b5404e2d6887fe7ecca5bd98e":[6,8,9,3,33],
-"group__spa__log.html#ga63ba8dd805c9b699e93ecf53ae1efed6":[6,8,9,3,15],
-"group__spa__log.html#ga73863d235426379d73a1defd3191877c":[6,8,9,3,40],
-"group__spa__log.html#ga750a6ac2af9bf84c4b59af14d6cbe22f":[6,8,9,3,12],
-"group__spa__log.html#ga7d4019336333f5cdf8b82514a6865b79":[6,8,9,3,37],
-"group__spa__log.html#ga8aeddf0fbcac9650fcfc23c58cf991d6":[6,8,9,3,23],
-"group__spa__log.html#ga90d35e35eb3b712e6a74f95c89562d72":[6,8,9,3,24],
-"group__spa__log.html#ga9680fab963b6dc9daf3c1cf2464e53f1":[6,8,9,3,5],
-"group__spa__log.html#ga9b5e43d9eae0e03aba5f126d31839cf1":[6,8,9,3,18],
-"group__spa__log.html#gaa8b31792643b981ff8a7313b26d9d6db":[6,8,9,3,20]
+"group__spa__log.html#ga63ba8dd805c9b699e93ecf53ae1efed6":[6,8,9,3,15]
 };
