@@ -6,9 +6,11 @@ var page_tools =
     [ "pw-cat", "page_man_pw_cat_1.html", null ],
     [ "pw-cli", "page_man_pw_cli_1.html", null ],
     [ "pw-dot", "page_man_pw_dot_1.html", null ],
+    [ "pw-link", "page_man_pw_link_1.html", null ],
     [ "pw-metadata", "page_man_pw_metadata_1.html", null ],
     [ "pw-mididump", "page_man_pw_mididump_1.html", null ],
     [ "pw-mon", "page_man_pw_mon_1.html", null ],
     [ "pw-profiler", "page_man_pw_profiler_1.html", null ],
+    [ "pw-top", "page_man_pw_top_1.html", null ],
     [ "pw-jack", "page_man_pw_jack_1.html", null ]
 ];
\ No newline at end of file
